==> openshift-model-config-6.0.0-sources.jar: io/fabric8/openshift/api/model/config/v1/OAuthSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OAuthSpecFluentImpl<A extends OAuthSpecFluent<A>> extends BaseFluent<A> implements OAuthSpecFluent<A>{
  public OAuthSpecFluentImpl() {
  }
  public OAuthSpecFluentImpl(OAuthSpec instance) {
    this.withIdentityProviders(instance.getIdentityProviders()); 
    this.withTemplates(instance.getTemplates()); 
    this.withTokenConfig(instance.getTokenConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ArrayList<IdentityProviderBuilder> identityProviders = new ArrayList<IdentityProviderBuilder>();
  private OAuthTemplatesBuilder templates;
  private TokenConfigBuilder tokenConfig;
  private Map<String,Object> additionalProperties;
  public A addToIdentityProviders(Integer index,IdentityProvider item) {
    if (this.identityProviders == null) {this.identityProviders = new ArrayList<IdentityProviderBuilder>();}
    IdentityProviderBuilder builder = new IdentityProviderBuilder(item);_visitables.get("identityProviders").add(index >= 0 ? index : _visitables.get("identityProviders").size(), builder);this.identityProviders.add(index >= 0 ? index : identityProviders.size(), builder); return (A)this;
  }
  public A setToIdentityProviders(Integer index,IdentityProvider item) {
    if (this.identityProviders == null) {this.identityProviders = new ArrayList<IdentityProviderBuilder>();}
    IdentityProviderBuilder builder = new IdentityProviderBuilder(item);
    if (index < 0 || index >= _visitables.get("identityProviders").size()) { _visitables.get("identityProviders").add(builder); } else { _visitables.get("identityProviders").set(index, builder);}
    if (index < 0 || index >= identityProviders.size()) { identityProviders.add(builder); } else { identityProviders.set(index, builder);}
     return (A)this;
  }
  public A addToIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... items) {
    if (this.identityProviders == null) {this.identityProviders = new ArrayList<IdentityProviderBuilder>();}
    for (IdentityProvider item : items) {IdentityProviderBuilder builder = new IdentityProviderBuilder(item);_visitables.get("identityProviders").add(builder);this.identityProviders.add(builder);} return (A)this;
  }
  public A addAllToIdentityProviders(Collection<IdentityProvider> items) {
    if (this.identityProviders == null) {this.identityProviders = new ArrayList<IdentityProviderBuilder>();}
    for (IdentityProvider item : items) {IdentityProviderBuilder builder = new IdentityProviderBuilder(item);_visitables.get("identityProviders").add(builder);this.identityProviders.add(builder);} return (A)this;
  }
  public A removeFromIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... items) {
    for (IdentityProvider item : items) {IdentityProviderBuilder builder = new IdentityProviderBuilder(item);_visitables.get("identityProviders").remove(builder);if (this.identityProviders != null) {this.identityProviders.remove(builder);}} return (A)this;
  }
  public A removeAllFromIdentityProviders(Collection<IdentityProvider> items) {
    for (IdentityProvider item : items) {IdentityProviderBuilder builder = new IdentityProviderBuilder(item);_visitables.get("identityProviders").remove(builder);if (this.identityProviders != null) {this.identityProviders.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromIdentityProviders(Predicate<IdentityProviderBuilder> predicate) {
    if (identityProviders == null) return (A) this;
    final Iterator<IdentityProviderBuilder> each = identityProviders.iterator();
    final List visitables = _visitables.get("identityProviders");
    while (each.hasNext()) {
      IdentityProviderBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildIdentityProviders instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IdentityProvider> getIdentityProviders() {
    return identityProviders != null ? build(identityProviders) : null;
  }
  public List<IdentityProvider> buildIdentityProviders() {
    return identityProviders != null ? build(identityProviders) : null;
  }
  public IdentityProvider buildIdentityProvider(Integer index) {
    return this.identityProviders.get(index).build();
  }
  public IdentityProvider buildFirstIdentityProvider() {
    return this.identityProviders.get(0).build();
  }
  public IdentityProvider buildLastIdentityProvider() {
    return this.identityProviders.get(identityProviders.size() - 1).build();
  }
  public IdentityProvider buildMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate) {
    for (IdentityProviderBuilder item: identityProviders) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate) {
    for (IdentityProviderBuilder item: identityProviders) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withIdentityProviders(List<IdentityProvider> identityProviders) {
    if (this.identityProviders != null) { _visitables.get("identityProviders").removeAll(this.identityProviders);}
    if (identityProviders != null) {this.identityProviders = new ArrayList(); for (IdentityProvider item : identityProviders){this.addToIdentityProviders(item);}} else { this.identityProviders = null;} return (A) this;
  }
  public A withIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... identityProviders) {
    if (this.identityProviders != null) {this.identityProviders.clear();}
    if (identityProviders != null) {for (IdentityProvider item :identityProviders){ this.addToIdentityProviders(item);}} return (A) this;
  }
  public Boolean hasIdentityProviders() {
    return identityProviders != null && !identityProviders.isEmpty();
  }
  public OAuthSpecFluent.IdentityProvidersNested<A> addNewIdentityProvider() {
    return new OAuthSpecFluentImpl.IdentityProvidersNestedImpl();
  }
  public OAuthSpecFluent.IdentityProvidersNested<A> addNewIdentityProviderLike(IdentityProvider item) {
    return new OAuthSpecFluentImpl.IdentityProvidersNestedImpl(-1, item);
  }
  public OAuthSpecFluent.IdentityProvidersNested<A> setNewIdentityProviderLike(Integer index,IdentityProvider item) {
    return new OAuthSpecFluentImpl.IdentityProvidersNestedImpl(index, item);
  }
  public OAuthSpecFluent.IdentityProvidersNested<A> editIdentityProvider(Integer index) {
    if (identityProviders.size() <= index) throw new RuntimeException("Can't edit identityProviders. Index exceeds size.");
    return setNewIdentityProviderLike(index, buildIdentityProvider(index));
  }
  public OAuthSpecFluent.IdentityProvidersNested<A> editFirstIdentityProvider() {
    if (identityProviders.size() == 0) throw new RuntimeException("Can't edit first identityProviders. The list is empty.");
    return setNewIdentityProviderLike(0, buildIdentityProvider(0));
  }
  public OAuthSpecFluent.IdentityProvidersNested<A> editLastIdentityProvider() {
    int index = identityProviders.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last identityProviders. The list is empty.");
    return setNewIdentityProviderLike(index, buildIdentityProvider(index));
  }
  public OAuthSpecFluent.IdentityProvidersNested<A> editMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate) {
    int index = -1;
    for (int i=0;i<identityProviders.size();i++) { 
    if (predicate.test(identityProviders.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching identityProviders. No match found.");
    return setNewIdentityProviderLike(index, buildIdentityProvider(index));
  }
  
  /**
   * This method has been deprecated, please use method buildTemplates instead.
   * @return The buildable object.
   */
  @Deprecated
  public OAuthTemplates getTemplates() {
    return this.templates!=null ?this.templates.build():null;
  }
  public OAuthTemplates buildTemplates() {
    return this.templates!=null ?this.templates.build():null;
  }
  public A withTemplates(OAuthTemplates templates) {
    _visitables.get("templates").remove(this.templates);
    if (templates!=null){ this.templates= new OAuthTemplatesBuilder(templates); _visitables.get("templates").add(this.templates);} else { this.templates = null; _visitables.get("templates").remove(this.templates); } return (A) this;
  }
  public Boolean hasTemplates() {
    return this.templates != null;
  }
  public OAuthSpecFluent.TemplatesNested<A> withNewTemplates() {
    return new OAuthSpecFluentImpl.TemplatesNestedImpl();
  }
  public OAuthSpecFluent.TemplatesNested<A> withNewTemplatesLike(OAuthTemplates item) {
    return new OAuthSpecFluentImpl.TemplatesNestedImpl(item);
  }
  public OAuthSpecFluent.TemplatesNested<A> editTemplates() {
    return withNewTemplatesLike(getTemplates());
  }
  public OAuthSpecFluent.TemplatesNested<A> editOrNewTemplates() {
    return withNewTemplatesLike(getTemplates() != null ? getTemplates(): new OAuthTemplatesBuilder().build());
  }
  public OAuthSpecFluent.TemplatesNested<A> editOrNewTemplatesLike(OAuthTemplates item) {
    return withNewTemplatesLike(getTemplates() != null ? getTemplates(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTokenConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public TokenConfig getTokenConfig() {
    return this.tokenConfig!=null ?this.tokenConfig.build():null;
  }
  public TokenConfig buildTokenConfig() {
    return this.tokenConfig!=null ?this.tokenConfig.build():null;
  }
  public A withTokenConfig(TokenConfig tokenConfig) {
    _visitables.get("tokenConfig").remove(this.tokenConfig);
    if (tokenConfig!=null){ this.tokenConfig= new TokenConfigBuilder(tokenConfig); _visitables.get("tokenConfig").add(this.tokenConfig);} else { this.tokenConfig = null; _visitables.get("tokenConfig").remove(this.tokenConfig); } return (A) this;
  }
  public Boolean hasTokenConfig() {
    return this.tokenConfig != null;
  }
  public OAuthSpecFluent.TokenConfigNested<A> withNewTokenConfig() {
    return new OAuthSpecFluentImpl.TokenConfigNestedImpl();
  }
  public OAuthSpecFluent.TokenConfigNested<A> withNewTokenConfigLike(TokenConfig item) {
    return new OAuthSpecFluentImpl.TokenConfigNestedImpl(item);
  }
  public OAuthSpecFluent.TokenConfigNested<A> editTokenConfig() {
    return withNewTokenConfigLike(getTokenConfig());
  }
  public OAuthSpecFluent.TokenConfigNested<A> editOrNewTokenConfig() {
    return withNewTokenConfigLike(getTokenConfig() != null ? getTokenConfig(): new TokenConfigBuilder().build());
  }
  public OAuthSpecFluent.TokenConfigNested<A> editOrNewTokenConfigLike(TokenConfig item) {
    return withNewTokenConfigLike(getTokenConfig() != null ? getTokenConfig(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OAuthSpecFluentImpl that = (OAuthSpecFluentImpl) o;
    if (identityProviders != null ? !identityProviders.equals(that.identityProviders) :that.identityProviders != null) return false;
    if (templates != null ? !templates.equals(that.templates) :that.templates != null) return false;
    if (tokenConfig != null ? !tokenConfig.equals(that.tokenConfig) :that.tokenConfig != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(identityProviders,  templates,  tokenConfig,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (identityProviders != null && !identityProviders.isEmpty()) { sb.append("identityProviders:"); sb.append(identityProviders + ","); }
    if (templates != null) { sb.append("templates:"); sb.append(templates + ","); }
    if (tokenConfig != null) { sb.append("tokenConfig:"); sb.append(tokenConfig + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class IdentityProvidersNestedImpl<N> extends IdentityProviderFluentImpl<OAuthSpecFluent.IdentityProvidersNested<N>> implements OAuthSpecFluent.IdentityProvidersNested<N>,Nested<N>{
    IdentityProvidersNestedImpl(Integer index,IdentityProvider item) {
      this.index = index;
      this.builder = new IdentityProviderBuilder(this, item);
    }
    IdentityProvidersNestedImpl() {
      this.index = -1;
      this.builder = new IdentityProviderBuilder(this);
    }
    IdentityProviderBuilder builder;
    Integer index;
    public N and() {
      return (N) OAuthSpecFluentImpl.this.setToIdentityProviders(index,builder.build());
    }
    public N endIdentityProvider() {
      return and();
    }
    
  }
  class TemplatesNestedImpl<N> extends OAuthTemplatesFluentImpl<OAuthSpecFluent.TemplatesNested<N>> implements OAuthSpecFluent.TemplatesNested<N>,Nested<N>{
    TemplatesNestedImpl(OAuthTemplates item) {
      this.builder = new OAuthTemplatesBuilder(this, item);
    }
    TemplatesNestedImpl() {
      this.builder = new OAuthTemplatesBuilder(this);
    }
    OAuthTemplatesBuilder builder;
    public N and() {
      return (N) OAuthSpecFluentImpl.this.withTemplates(builder.build());
    }
    public N endTemplates() {
      return and();
    }
    
  }
  class TokenConfigNestedImpl<N> extends TokenConfigFluentImpl<OAuthSpecFluent.TokenConfigNested<N>> implements OAuthSpecFluent.TokenConfigNested<N>,Nested<N>{
    TokenConfigNestedImpl(TokenConfig item) {
      this.builder = new TokenConfigBuilder(this, item);
    }
    TokenConfigNestedImpl() {
      this.builder = new TokenConfigBuilder(this);
    }
    TokenConfigBuilder builder;
    public N and() {
      return (N) OAuthSpecFluentImpl.this.withTokenConfig(builder.build());
    }
    public N endTokenConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/OAuthSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OAuthSpecFluentImpl<A extends OAuthSpecFluent<A>> extends BaseFluent<A> implements OAuthSpecFluent<A>{
  public OAuthSpecFluentImpl() {
  }
  public OAuthSpecFluentImpl(OAuthSpec instance) {
    if (instance != null) {
      this.withIdentityProviders(instance.getIdentityProviders());
      this.withTemplates(instance.getTemplates());
      this.withTokenConfig(instance.getTokenConfig());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ArrayList<IdentityProviderBuilder> identityProviders = new ArrayList<IdentityProviderBuilder>();
  private OAuthTemplatesBuilder templates;
  private TokenConfigBuilder tokenConfig;
  private Map<String,Object> additionalProperties;
  public A addToIdentityProviders(int index,IdentityProvider item) {
    if (this.identityProviders == null) {this.identityProviders = new ArrayList<IdentityProviderBuilder>();}
    IdentityProviderBuilder builder = new IdentityProviderBuilder(item);
    if (index < 0 || index >= identityProviders.size()) { _visitables.get("identityProviders").add(builder); identityProviders.add(builder); } else { _visitables.get("identityProviders").add(index, builder); identityProviders.add(index, builder);}
    return (A)this;
  }
  public A setToIdentityProviders(int index,IdentityProvider item) {
    if (this.identityProviders == null) {this.identityProviders = new ArrayList<IdentityProviderBuilder>();}
    IdentityProviderBuilder builder = new IdentityProviderBuilder(item);
    if (index < 0 || index >= identityProviders.size()) { _visitables.get("identityProviders").add(builder); identityProviders.add(builder); } else { _visitables.get("identityProviders").set(index, builder); identityProviders.set(index, builder);}
    return (A)this;
  }
  public A addToIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... items) {
    if (this.identityProviders == null) {this.identityProviders = new ArrayList<IdentityProviderBuilder>();}
    for (IdentityProvider item : items) {IdentityProviderBuilder builder = new IdentityProviderBuilder(item);_visitables.get("identityProviders").add(builder);this.identityProviders.add(builder);} return (A)this;
  }
  public A addAllToIdentityProviders(Collection<IdentityProvider> items) {
    if (this.identityProviders == null) {this.identityProviders = new ArrayList<IdentityProviderBuilder>();}
    for (IdentityProvider item : items) {IdentityProviderBuilder builder = new IdentityProviderBuilder(item);_visitables.get("identityProviders").add(builder);this.identityProviders.add(builder);} return (A)this;
  }
  public A removeFromIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... items) {
    for (IdentityProvider item : items) {IdentityProviderBuilder builder = new IdentityProviderBuilder(item);_visitables.get("identityProviders").remove(builder);if (this.identityProviders != null) {this.identityProviders.remove(builder);}} return (A)this;
  }
  public A removeAllFromIdentityProviders(Collection<IdentityProvider> items) {
    for (IdentityProvider item : items) {IdentityProviderBuilder builder = new IdentityProviderBuilder(item);_visitables.get("identityProviders").remove(builder);if (this.identityProviders != null) {this.identityProviders.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromIdentityProviders(Predicate<IdentityProviderBuilder> predicate) {
    if (identityProviders == null) return (A) this;
    final Iterator<IdentityProviderBuilder> each = identityProviders.iterator();
    final List visitables = _visitables.get("identityProviders");
    while (each.hasNext()) {
      IdentityProviderBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildIdentityProviders instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IdentityProvider> getIdentityProviders() {
    return identityProviders != null ? build(identityProviders) : null;
  }
  public List<IdentityProvider> buildIdentityProviders() {
    return identityProviders != null ? build(identityProviders) : null;
  }
  public IdentityProvider buildIdentityProvider(int index) {
    return this.identityProviders.get(index).build();
  }
  public IdentityProvider buildFirstIdentityProvider() {
    return this.identityProviders.get(0).build();
  }
  public IdentityProvider buildLastIdentityProvider() {
    return this.identityProviders.get(identityProviders.size() - 1).build();
  }
  public IdentityProvider buildMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate) {
    for (IdentityProviderBuilder item: identityProviders) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate) {
    for (IdentityProviderBuilder item: identityProviders) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withIdentityProviders(List<IdentityProvider> identityProviders) {
    if (this.identityProviders != null) { _visitables.get("identityProviders").clear();}
    if (identityProviders != null) {this.identityProviders = new ArrayList(); for (IdentityProvider item : identityProviders){this.addToIdentityProviders(item);}} else { this.identityProviders = null;} return (A) this;
  }
  public A withIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... identityProviders) {
    if (this.identityProviders != null) {this.identityProviders.clear(); _visitables.remove("identityProviders"); }
    if (identityProviders != null) {for (IdentityProvider item :identityProviders){ this.addToIdentityProviders(item);}} return (A) this;
  }
  public Boolean hasIdentityProviders() {
    return identityProviders != null && !identityProviders.isEmpty();
  }
  public OAuthSpecFluentImpl.IdentityProvidersNested<A> addNewIdentityProvider() {
    return new OAuthSpecFluentImpl.IdentityProvidersNestedImpl();
  }
  public OAuthSpecFluentImpl.IdentityProvidersNested<A> addNewIdentityProviderLike(IdentityProvider item) {
    return new OAuthSpecFluentImpl.IdentityProvidersNestedImpl(-1, item);
  }
  public OAuthSpecFluentImpl.IdentityProvidersNested<A> setNewIdentityProviderLike(int index,IdentityProvider item) {
    return new OAuthSpecFluentImpl.IdentityProvidersNestedImpl(index, item);
  }
  public OAuthSpecFluentImpl.IdentityProvidersNested<A> editIdentityProvider(int index) {
    if (identityProviders.size() <= index) throw new RuntimeException("Can't edit identityProviders. Index exceeds size.");
    return setNewIdentityProviderLike(index, buildIdentityProvider(index));
  }
  public OAuthSpecFluentImpl.IdentityProvidersNested<A> editFirstIdentityProvider() {
    if (identityProviders.size() == 0) throw new RuntimeException("Can't edit first identityProviders. The list is empty.");
    return setNewIdentityProviderLike(0, buildIdentityProvider(0));
  }
  public OAuthSpecFluentImpl.IdentityProvidersNested<A> editLastIdentityProvider() {
    int index = identityProviders.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last identityProviders. The list is empty.");
    return setNewIdentityProviderLike(index, buildIdentityProvider(index));
  }
  public OAuthSpecFluentImpl.IdentityProvidersNested<A> editMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate) {
    int index = -1;
    for (int i=0;i<identityProviders.size();i++) { 
    if (predicate.test(identityProviders.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching identityProviders. No match found.");
    return setNewIdentityProviderLike(index, buildIdentityProvider(index));
  }
  
  /**
   * This method has been deprecated, please use method buildTemplates instead.
   * @return The buildable object.
   */
  @Deprecated
  public OAuthTemplates getTemplates() {
    return this.templates!=null ?this.templates.build():null;
  }
  public OAuthTemplates buildTemplates() {
    return this.templates!=null ?this.templates.build():null;
  }
  public A withTemplates(OAuthTemplates templates) {
    _visitables.get("templates").remove(this.templates);
    if (templates!=null){ this.templates= new OAuthTemplatesBuilder(templates); _visitables.get("templates").add(this.templates);} else { this.templates = null; _visitables.get("templates").remove(this.templates); } return (A) this;
  }
  public Boolean hasTemplates() {
    return this.templates != null;
  }
  public OAuthSpecFluentImpl.TemplatesNested<A> withNewTemplates() {
    return new OAuthSpecFluentImpl.TemplatesNestedImpl();
  }
  public OAuthSpecFluentImpl.TemplatesNested<A> withNewTemplatesLike(OAuthTemplates item) {
    return new OAuthSpecFluentImpl.TemplatesNestedImpl(item);
  }
  public OAuthSpecFluentImpl.TemplatesNested<A> editTemplates() {
    return withNewTemplatesLike(getTemplates());
  }
  public OAuthSpecFluentImpl.TemplatesNested<A> editOrNewTemplates() {
    return withNewTemplatesLike(getTemplates() != null ? getTemplates(): new OAuthTemplatesBuilder().build());
  }
  public OAuthSpecFluentImpl.TemplatesNested<A> editOrNewTemplatesLike(OAuthTemplates item) {
    return withNewTemplatesLike(getTemplates() != null ? getTemplates(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTokenConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public TokenConfig getTokenConfig() {
    return this.tokenConfig!=null ?this.tokenConfig.build():null;
  }
  public TokenConfig buildTokenConfig() {
    return this.tokenConfig!=null ?this.tokenConfig.build():null;
  }
  public A withTokenConfig(TokenConfig tokenConfig) {
    _visitables.get("tokenConfig").remove(this.tokenConfig);
    if (tokenConfig!=null){ this.tokenConfig= new TokenConfigBuilder(tokenConfig); _visitables.get("tokenConfig").add(this.tokenConfig);} else { this.tokenConfig = null; _visitables.get("tokenConfig").remove(this.tokenConfig); } return (A) this;
  }
  public Boolean hasTokenConfig() {
    return this.tokenConfig != null;
  }
  public OAuthSpecFluentImpl.TokenConfigNested<A> withNewTokenConfig() {
    return new OAuthSpecFluentImpl.TokenConfigNestedImpl();
  }
  public OAuthSpecFluentImpl.TokenConfigNested<A> withNewTokenConfigLike(TokenConfig item) {
    return new OAuthSpecFluentImpl.TokenConfigNestedImpl(item);
  }
  public OAuthSpecFluentImpl.TokenConfigNested<A> editTokenConfig() {
    return withNewTokenConfigLike(getTokenConfig());
  }
  public OAuthSpecFluentImpl.TokenConfigNested<A> editOrNewTokenConfig() {
    return withNewTokenConfigLike(getTokenConfig() != null ? getTokenConfig(): new TokenConfigBuilder().build());
  }
  public OAuthSpecFluentImpl.TokenConfigNested<A> editOrNewTokenConfigLike(TokenConfig item) {
    return withNewTokenConfigLike(getTokenConfig() != null ? getTokenConfig(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OAuthSpecFluentImpl that = (OAuthSpecFluentImpl) o;
    if (!java.util.Objects.equals(identityProviders, that.identityProviders)) return false;

    if (!java.util.Objects.equals(templates, that.templates)) return false;

    if (!java.util.Objects.equals(tokenConfig, that.tokenConfig)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(identityProviders,  templates,  tokenConfig,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (identityProviders != null) { sb.append("identityProviders:"); sb.append(identityProviders + ","); }
    if (templates != null) { sb.append("templates:"); sb.append(templates + ","); }
    if (tokenConfig != null) { sb.append("tokenConfig:"); sb.append(tokenConfig + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class IdentityProvidersNestedImpl<N> extends IdentityProviderFluentImpl<OAuthSpecFluentImpl.IdentityProvidersNested<N>> implements OAuthSpecFluentImpl.IdentityProvidersNested<N>,Nested<N>{
    IdentityProvidersNestedImpl(int index,IdentityProvider item) {
      this.index = index;
      this.builder = new IdentityProviderBuilder(this, item);
    }
    IdentityProvidersNestedImpl() {
      this.index = -1;
      this.builder = new IdentityProviderBuilder(this);
    }
    IdentityProviderBuilder builder;
    int index;
    public N and() {
      return (N) OAuthSpecFluentImpl.this.setToIdentityProviders(index,builder.build());
    }
    public N endIdentityProvider() {
      return and();
    }
    
  }
  class TemplatesNestedImpl<N> extends OAuthTemplatesFluentImpl<OAuthSpecFluentImpl.TemplatesNested<N>> implements OAuthSpecFluentImpl.TemplatesNested<N>,Nested<N>{
    TemplatesNestedImpl(OAuthTemplates item) {
      this.builder = new OAuthTemplatesBuilder(this, item);
    }
    TemplatesNestedImpl() {
      this.builder = new OAuthTemplatesBuilder(this);
    }
    OAuthTemplatesBuilder builder;
    public N and() {
      return (N) OAuthSpecFluentImpl.this.withTemplates(builder.build());
    }
    public N endTemplates() {
      return and();
    }
    
  }
  class TokenConfigNestedImpl<N> extends TokenConfigFluentImpl<OAuthSpecFluentImpl.TokenConfigNested<N>> implements OAuthSpecFluentImpl.TokenConfigNested<N>,Nested<N>{
    TokenConfigNestedImpl(TokenConfig item) {
      this.builder = new TokenConfigBuilder(this, item);
    }
    TokenConfigNestedImpl() {
      this.builder = new TokenConfigBuilder(this);
    }
    TokenConfigBuilder builder;
    public N and() {
      return (N) OAuthSpecFluentImpl.this.withTokenConfig(builder.build());
    }
    public N endTokenConfig() {
      return and();
    }
    
  }
  
}
